@@ -82,7 +82,7 @@ class Stream:
 
     def sorted(self, comparator: Optional[Comparator] = None, reverse=False) -> 'Stream':
         async def fn(iterable: AsyncGenerator) -> AsyncGenerator:
-            # unfortunately I dont se now other way than to block the entire stream
+            # unfortunately I now don't see other way than to block the entire stream
             # how can I otherwise know what is the first item out?
             cache = []
             async for i in iterable:
@@ -203,3 +203,37 @@ class Stream:
                 else:
                     return False
         return True
+
+    async def none_match(self, predicate: Predicate) -> bool:
+        async for n in self._compose(self._chain, self._stream):
+            if iscoroutinefunction(predicate):
+                if await predicate(n):
+                    return False
+                else:
+                    continue
+            else:
+                if predicate(n):
+                    return False
+                else:
+                    continue
+        return True
+
+    async def any_match(self, predicate: Predicate) -> bool:
+        async for n in self._compose(self._chain, self._stream):
+            if iscoroutinefunction(predicate):
+                if await predicate(n):
+                    return True
+                else:
+                    continue
+            else:
+                if predicate(n):
+                    return True
+                else:
+                    continue
+        return False
+
+    async def count(self) -> int:
+        c = 0
+        async for _ in self._compose(self._chain, self._stream):
+            c += 1
+        return c
